AttendeeModel class

Constructors

AttendeeModel(String attendeeId, String externalUserId, {DateTime? joinedAt})
AttendeeModel.fromJson(dynamic json)
factory

Properties

attendeeId → String
final
externalUserId → String
final
hashCode → int
The hash code for this object.
no setterinherited
isVideoOn ↔ bool
getter/setter pair
joinedAt → DateTime
final
muteStatus ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoTile ↔ VideoTileModel?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited