MediaPlacement class

Constructors

MediaPlacement(String audioHostUrl, String audioFallbackUrl, String signalingUrl, String turnControllerUrl)
MediaPlacement.fromJson(Map<String, dynamic> json)
factory

Properties

audioFallbackUrl → String
final
audioHostUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signalingUrl → String
final
turnControllerUrl → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited