MeetingTheme class

Constructors

MeetingTheme()
factory

Properties

actionViewHeight double
getter/setter pair
audioActiveColor Color
getter/setter pair
baseUnit double
getter/setter pair
chatMessageTextStyle TextStyle
getter/setter pair
chatNameTextStyle TextStyle
getter/setter pair
chatSelfNameTextStyle TextStyle
getter/setter pair
dotActiveColor Color
getter/setter pair
errorBackground Color
getter/setter pair
errorTextStyle TextStyle
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageViewHeight double
getter/setter pair
messageViewWidth double
getter/setter pair
nameTextStyle TextStyle
getter/setter pair
pageAttendeeSize int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited