MessageModel class

Constructors

MessageModel(String attendeeId, String externalUserId, String message, String topic, num timestampMs, {bool? throttled})
MessageModel.fromJson(dynamic json)
factory

Properties

attendeeId → String
final
externalUserId → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
throttled → bool?
final
timestampMs → num
final
topic → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited