VideoTileModel class

Constructors

VideoTileModel(int tileId, int videoStreamContentWidth, int videoStreamContentHeight, bool isLocalTile, bool isContentShare)
VideoTileModel.fromJson(dynamic json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isContentShare ↔ bool
getter/setter pair
isLocalTile ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tileId → int
final
videoStreamContentHeight ↔ int
getter/setter pair
videoStreamContentWidth ↔ int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited